@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.31";
+our $VERSION = "1.32";
 
 use v5.14;
 use warnings;
@@ -14,7 +14,6 @@ Configure qw(bundling);
 
 use Data::Dumper;
 use List::Util qw(max sum);
-use Hash::Util qw(lock_keys lock_keys_plus unlock_keys);
 use Text::ANSI::Fold qw(ansi_fold);
 use Text::ANSI::Fold::Util qw(ansi_width);
 use Text::ANSI::Printf qw(ansi_printf ansi_sprintf);
@@ -43,6 +42,8 @@ use Getopt::EX::Hashed 1.05; {
     has output_separator    => ' =s o    ' , default => '  ' ;
     has document            => '    D    ' ;
     has parallel            => ' !  V    ' ;
+    has filename            => ' !  H    ' ;
+    has filename_format     => ' =s      ' , default => ': %s';
     has pages               => ' !       ' ;
     has up                  => ' :i U    ' ;
     has page                => ' :i P    ' , min => 0;
@@ -75,7 +76,6 @@ use Getopt::EX::Hashed 1.05; {
     has discard_el          => ' !       ' , default => 1 ;
     has padchar             => ' =s      ' , default => ' ' ;
     has colormap            => ' =s@  cm ' , default => [] ;
-    has filename            => ' !  H    ' ;
 
     has '+boundary'  => any => [ qw(none word space) ] ;
     has '+linestyle' => any => [ qw(none wordwrap wrap truncate) ] ;
@@ -175,7 +175,7 @@ sub perform {
 
     warn Dumper $obj if $obj->debug;
 
-    my @files = $obj->read_files(@ARGV ? @ARGV : '-');
+    my @files = $obj->read_files(@ARGV ? @ARGV : '-') or return 1;
 
     if ($obj->table) {
 	my @lines = map { @{$_->{data}} } @files;
@@ -280,10 +280,10 @@ sub parallel_out {
 	my $max_length = max map { int @{$_->{data}} } @rows;
 	if ($obj->filename) {
 	    my $w = $obj->span + $obj->border_width('center');
-	    for (@rows) {
-		printf "%-*.*s", $w, $w, $_->{name};
-	    }
-	    print "\n";
+	    my $format = "%-${w}.${w}s" x (@rows - 1) . "%s\n";
+	    printf $format, map {
+		sprintf $obj->filename_format, $_->{name};
+	    } @rows;
 	}
 	$obj->column_out(map {
 	    my $data = $_->{data};
@@ -318,7 +318,10 @@ sub read_files {
     my @files;
     for my $file (@_) {
 	open my $fh, $file or die "$file: $!";
-	my $content = do { local $/; <$fh> };
+	my $content = do { local $/; <$fh> } // do {
+	    warn "$file: $!\n" if $!;
+	    next;
+	};
 	my @data = $obj->pages ? split(/\f/, $content) : $content;
 	for my $data (@data) {
 	    my @line = split /\n/, $data;
@@ -360,14 +363,14 @@ sub set_horizontal {
 
     my $span;
     my $panes;
+    my $claim = sum($max_data_length,
+		    $obj->runin_margin,
+		    $obj->border_width('center') || $obj->margin);
     if ($obj->widen and not $obj->pane_width) {
-	my $min = $max_data_length + ($obj->border_width('center') || 1);
-	$panes = $obj->pane || $width / $min || 1;
+	$panes = $obj->pane || $width / $claim || 1;
 	$span = ($width + $obj->border_width('center')) / $panes;
     } else {
-	$span = $obj->pane_width ||
-	    roundup($max_data_length + ($obj->border_width('center') || $obj->margin),
-		    $unit);
+	$span = $obj->pane_width || roundup($claim, $unit);
 	$panes = $obj->pane || $width / $span || 1;
     }
     $span -= $obj->border_width('center');
@@ -381,7 +384,7 @@ sub set_horizontal {
 sub set_contents {
     my $obj = shift;
     my $dp = shift;
-    (my $cell_width = $obj->span - $obj->margin_width) < 1
+    (my $cell_width = $obj->span - $obj->runin_margin) < 1
 	and die "Not enough space.\n";
     # Fold long lines
     if ($obj->linestyle and $obj->linestyle ne 'none') {
